============
Basics usage
============

.. include:: tutorials/getting_started_tutorial.rst
.. include:: tutorials/configuring.rst
.. include:: tutorials/basic_interaction.rst
.. include:: tutorials/pandas.rst
.. include:: tutorials/data_mining.rst
.. include:: tutorials/the_cellpy_cmd.rst
